pub struct MemoryStore { /* private fields */ }Expand description
A thread-safe in-memory cache store backed by DashMap.
Implementations
Sourceimpl MemoryStore
impl MemoryStore
Sourcepub fn read_with_options(
&self,
key: &str,
options: &CacheOptions,
) -> Option<Value>
pub fn read_with_options( &self, key: &str, options: &CacheOptions, ) -> Option<Value>
Reads a cached value using explicit options such as version matching.
Sourcepub fn exist_with_options(&self, key: &str, options: &CacheOptions) -> bool
pub fn exist_with_options(&self, key: &str, options: &CacheOptions) -> bool
Returns true when a live entry exists for key under the given options.