pub enum VerifierError {
InvalidSignature,
Expired,
PurposeMismatch,
Encoding(String),
}Expand description
Errors returned by MessageVerifier.
Variants
InvalidSignature
The message signature is invalid or the message is malformed.
Expired
The message has expired.
PurposeMismatch
The message purpose does not match the expected purpose.
Encoding(String)
The message could not be encoded or decoded.