pub struct MessageEncryptor { /* private fields */ }Expand description
Encrypts messages using AES-256-GCM.
Implementations
Sourceimpl MessageEncryptor
impl MessageEncryptor
Sourcepub fn new(secret: &[u8]) -> Result<Self, EncryptorError>
pub fn new(secret: &[u8]) -> Result<Self, EncryptorError>
Creates a new encryptor from a 32-byte secret.
Sourcepub fn encrypt_and_sign(&self, data: &[u8]) -> Result<String, EncryptorError>
pub fn encrypt_and_sign(&self, data: &[u8]) -> Result<String, EncryptorError>
Encrypts and authenticates raw bytes.
Sourcepub fn encrypt_and_sign_with_purpose(
&self,
data: &[u8],
purpose: &str,
expires_at: Option<DateTime<Utc>>,
) -> Result<String, EncryptorError>
pub fn encrypt_and_sign_with_purpose( &self, data: &[u8], purpose: &str, expires_at: Option<DateTime<Utc>>, ) -> Result<String, EncryptorError>
Encrypts and authenticates raw bytes with purpose confinement and optional expiration.
Sourcepub fn decrypt_and_verify(
&self,
encrypted_message: &str,
) -> Result<Vec<u8>, EncryptorError>
pub fn decrypt_and_verify( &self, encrypted_message: &str, ) -> Result<Vec<u8>, EncryptorError>
Decrypts and verifies an encrypted message.
Sourcepub fn decrypt_and_verify_with_purpose(
&self,
encrypted_message: &str,
purpose: &str,
) -> Result<Vec<u8>, EncryptorError>
pub fn decrypt_and_verify_with_purpose( &self, encrypted_message: &str, purpose: &str, ) -> Result<Vec<u8>, EncryptorError>
Decrypts and verifies an encrypted message for a specific purpose.