pub struct MessageVerifier { /* private fields */ }Expand description
Signs messages using HMAC-SHA256.
Implementations
Sourceimpl MessageVerifier
impl MessageVerifier
Sourcepub fn generate(&self, data: &[u8]) -> String
pub fn generate(&self, data: &[u8]) -> String
Generates a signed message in the form base64(payload)--base64(hmac).
Sourcepub fn generate_with_purpose(
&self,
data: &[u8],
purpose: &str,
expires_at: Option<DateTime<Utc>>,
) -> String
pub fn generate_with_purpose( &self, data: &[u8], purpose: &str, expires_at: Option<DateTime<Utc>>, ) -> String
Generates a signed message with purpose confinement and optional expiration.
Sourcepub fn verify(&self, signed_message: &str) -> Result<Vec<u8>, VerifierError>
pub fn verify(&self, signed_message: &str) -> Result<Vec<u8>, VerifierError>
Verifies a signed message and returns the original bytes.
Sourcepub fn verify_with_purpose(
&self,
signed_message: &str,
purpose: &str,
) -> Result<Vec<u8>, VerifierError>
pub fn verify_with_purpose( &self, signed_message: &str, purpose: &str, ) -> Result<Vec<u8>, VerifierError>
Verifies a signed message and enforces its purpose.
Sourcepub fn valid_message(&self, signed_message: &str) -> bool
pub fn valid_message(&self, signed_message: &str) -> bool
Returns true when the message has a valid signature.