pub struct RotatingVerifier { /* private fields */ }Expand description
Tries multiple verifiers until one succeeds.
Implementations
Sourceimpl RotatingVerifier
impl RotatingVerifier
Sourcepub fn new(verifiers: Vec<MessageVerifier>) -> Self
pub fn new(verifiers: Vec<MessageVerifier>) -> Self
Creates a rotating verifier with the newest verifier first.
Sourcepub fn generate(&self, data: &[u8]) -> String
pub fn generate(&self, data: &[u8]) -> String
Generates a signed message using the newest verifier.
Sourcepub fn generate_with_purpose(
&self,
data: &[u8],
purpose: &str,
expires_at: Option<DateTime<Utc>>,
) -> String
pub fn generate_with_purpose( &self, data: &[u8], purpose: &str, expires_at: Option<DateTime<Utc>>, ) -> String
Generates a signed message with purpose using the newest verifier.
Sourcepub fn verify(&self, signed_message: &str) -> Result<Vec<u8>, VerifierError>
pub fn verify(&self, signed_message: &str) -> Result<Vec<u8>, VerifierError>
Verifies a signed message with all configured verifiers.
Sourcepub fn verify_with_purpose(
&self,
signed_message: &str,
purpose: &str,
) -> Result<Vec<u8>, VerifierError>
pub fn verify_with_purpose( &self, signed_message: &str, purpose: &str, ) -> Result<Vec<u8>, VerifierError>
Verifies a signed message with purpose using all configured verifiers.
Sourcepub fn valid_message(&self, signed_message: &str) -> bool
pub fn valid_message(&self, signed_message: &str) -> bool
Returns true when any configured verifier accepts the message.