Module testing

Module testing 

Structs

TimeFreezeGuard
A guard that restores the previously frozen time when dropped.

Functions

assert_changes
Asserts that a shared value changed to the expected state during closure execution.
assert_difference
Asserts that a numeric value changed by the expected amount during closure execution.
assert_no_changes
Asserts that a computed value did not change during closure execution.
assert_no_difference
Asserts that a numeric value did not change during closure execution.
freeze_time
Freezes the current testing time until the returned guard is dropped.