StringExt

Trait StringExt 

pub trait StringExt {
Show 20 methods // Required methods fn is_blank(&self) -> bool; fn truncate_with(&self, length: usize, omission: &str) -> String; fn truncate_words_with(&self, count: usize, omission: &str) -> String; fn squish(&self) -> String; fn remove(&self, pattern: &str) -> String; fn presence(&self) -> Option<&str>; fn camelize(&self) -> String; fn underscore(&self) -> String; fn dasherize(&self) -> String; fn titleize(&self) -> String; fn tableize(&self) -> String; fn classify(&self) -> String; fn pluralize(&self) -> String; fn singularize(&self) -> String; fn humanize(&self) -> String; fn foreign_key(&self) -> String; fn parameterize(&self) -> String; // Provided methods fn is_present(&self) -> bool { ... } fn truncate(&self, length: usize) -> String { ... } fn truncate_words(&self, count: usize) -> String { ... }
}
Extension trait for string-like types.

Required Methods

fn is_blank(&self) -> bool

Returns true if the string is empty or contains only whitespace.

fn truncate_with(&self, length: usize, omission: &str) -> String

Truncates to length characters, appending omission when needed.

fn truncate_words_with(&self, count: usize, omission: &str) -> String

Truncates on word boundary, appending omission when needed.

fn squish(&self) -> String

Strips leading/trailing whitespace and collapses internal whitespace to a single space.

fn remove(&self, pattern: &str) -> String

Removes all occurrences of the pattern from the string.

fn presence(&self) -> Option<&str>

Returns the string if present, otherwise None.

fn camelize(&self) -> String

Converts to CamelCase.

fn underscore(&self) -> String

Converts to snake_case.

fn dasherize(&self) -> String

Converts to dash-case.

fn titleize(&self) -> String

Converts to Title Case.

fn tableize(&self) -> String

Converts to a table name.

fn classify(&self) -> String

Converts to a class name.

fn pluralize(&self) -> String

Converts to plural form.

fn singularize(&self) -> String

Converts to singular form.

fn humanize(&self) -> String

Converts to a humanized form.

fn foreign_key(&self) -> String

Creates a foreign key name.

fn parameterize(&self) -> String

Creates a URL-friendly slug.

Provided Methods

fn is_present(&self) -> bool

Returns true if the string is not blank.

fn truncate(&self, length: usize) -> String

Truncates to length characters, appending ... when needed.

fn truncate_words(&self, count: usize) -> String

Truncates on word boundary, appending ... when needed.

Implementations on Foreign Types

Source

impl StringExt for str

Source

fn is_blank(&self) -> bool

Source

fn truncate_with(&self, length: usize, omission: &str) -> String

Source

fn truncate_words_with(&self, count: usize, omission: &str) -> String

Source

fn squish(&self) -> String

Source

fn remove(&self, pattern: &str) -> String

Source

fn presence(&self) -> Option<&str>

Source

fn camelize(&self) -> String

Source

fn underscore(&self) -> String

Source

fn dasherize(&self) -> String

Source

fn titleize(&self) -> String

Source

fn tableize(&self) -> String

Source

fn classify(&self) -> String

Source

fn pluralize(&self) -> String

Source

fn singularize(&self) -> String

Source

fn humanize(&self) -> String

Source

fn foreign_key(&self) -> String

Source

fn parameterize(&self) -> String

Source

impl StringExt for String

Source

fn is_blank(&self) -> bool

Source

fn truncate_with(&self, length: usize, omission: &str) -> String

Source

fn truncate_words_with(&self, count: usize, omission: &str) -> String

Source

fn squish(&self) -> String

Source

fn remove(&self, pattern: &str) -> String

Source

fn presence(&self) -> Option<&str>

Source

fn camelize(&self) -> String

Source

fn underscore(&self) -> String

Source

fn dasherize(&self) -> String

Source

fn titleize(&self) -> String

Source

fn tableize(&self) -> String

Source

fn classify(&self) -> String

Source

fn pluralize(&self) -> String

Source

fn singularize(&self) -> String

Source

fn humanize(&self) -> String

Source

fn foreign_key(&self) -> String

Source

fn parameterize(&self) -> String

Implementors